import { EventEmitter } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Component for PDF controls (navigation, zoom, etc.)
 */
export declare class PdfControlsComponent {
    currentPage: number;
    totalPages: number;
    zoom: number;
    rotation: number;
    showNavigation: boolean;
    showZoomControls: boolean;
    showRotationControls: boolean;
    showDownloadButton: boolean;
    showPrintButton: boolean;
    showSearchBar: boolean;
    showThumbnails: boolean;
    showOutline: boolean;
    pageChange: EventEmitter<number>;
    zoomChange: EventEmitter<number>;
    rotationChange: EventEmitter<number>;
    download: EventEmitter<void>;
    print: EventEmitter<void>;
    search: EventEmitter<string>;
    toggleThumbnails: EventEmitter<boolean>;
    toggleOutline: EventEmitter<boolean>;
    /**
     * Navigate to first page
     */
    onFirstPage(): void;
    /**
     * Navigate to previous page
     */
    onPreviousPage(): void;
    /**
     * Navigate to next page
     */
    onNextPage(): void;
    /**
     * Navigate to last page
     */
    onLastPage(): void;
    /**
     * Handle direct page number input
     * @param page The new page number
     */
    onPageInputChange(page: number): void;
    /**
     * Increase zoom by 20%
     */
    onZoomIn(): void;
    /**
     * Decrease zoom by 20%
     */
    onZoomOut(): void;
    /**
     * Handle zoom dropdown selection
     * @param zoom The selected zoom level
     */
    onZoomSelect(zoom: number): void;
    /**
     * Rotate counterclockwise by 90 degrees
     */
    onRotateLeft(): void;
    /**
     * Rotate clockwise by 90 degrees
     */
    onRotateRight(): void;
    /**
     * Trigger document download
     */
    onDownload(): void;
    /**
     * Trigger document printing
     */
    onPrint(): void;
    /**
     * Execute search if text is provided
     * @param text The text to search for
     */
    onSearch(text: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PdfControlsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PdfControlsComponent, "ng-pdf-controls", never, { "currentPage": { "alias": "currentPage"; "required": false; }; "totalPages": { "alias": "totalPages"; "required": false; }; "zoom": { "alias": "zoom"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "showNavigation": { "alias": "showNavigation"; "required": false; }; "showZoomControls": { "alias": "showZoomControls"; "required": false; }; "showRotationControls": { "alias": "showRotationControls"; "required": false; }; "showDownloadButton": { "alias": "showDownloadButton"; "required": false; }; "showPrintButton": { "alias": "showPrintButton"; "required": false; }; "showSearchBar": { "alias": "showSearchBar"; "required": false; }; "showThumbnails": { "alias": "showThumbnails"; "required": false; }; "showOutline": { "alias": "showOutline"; "required": false; }; }, { "pageChange": "pageChange"; "zoomChange": "zoomChange"; "rotationChange": "rotationChange"; "download": "download"; "print": "print"; "search": "search"; "toggleThumbnails": "toggleThumbnails"; "toggleOutline": "toggleOutline"; }, never, never, true, never>;
}
